import { __decorate } from "tslib";
import { css, html, observable, ref } from '@microsoft/fast-element';
import { FoundationElement } from '@microsoft/fast-foundation';
import { EDITED_COLUMN_FIELD } from '../grid-pro.types';
/**
 * The AG String Editor element.
 * @public
 * @tagname %%prefix%%-string-editor
 */
export class StringEditor extends FoundationElement {
    init(params) {
        if (!params)
            return;
        this.params = params;
        this.value = params.value;
        this.actualWidth = params.column.getActualWidth();
    }
    getGui() {
        return this;
    }
    refresh(params) {
        return true;
    }
    getValue() {
        return this.value;
    }
    isPopup() {
        return true;
    }
    afterGuiAttached() {
        this.input.focus();
    }
    changeHandler(event) {
        this.value = event.target.value;
    }
    isCancelBeforeStart() {
        return !!this.params.data[EDITED_COLUMN_FIELD];
    }
}
__decorate([
    observable
], StringEditor.prototype, "params", void 0);
__decorate([
    observable
], StringEditor.prototype, "value", void 0);
__decorate([
    observable
], StringEditor.prototype, "actualWidth", void 0);
/**
 * The AG String Renderer Styles.
 * @public
 */
export const agStringEditorStyles = css `
  :host {
    display: flex;
  }
`;
/**
 * Get a Design System prefixed String template.
 * @param designSystem - The design system prefix to use. Defaults to 'foundation'.
 * @returns A String component template prefixed with the correct design system.
 * @public
 */
export const getStringEditorTemplate = (designSystem = 'foundation') => html `
  <${designSystem}-text-field
    ${ref('input')}
    :value=${(x) => (x.value === undefined ? '' : x.value)}
    @input=${(x, c) => {
    x.changeHandler(c.event);
}}
    placeholder=${(x) => x.params.placeholder}
    style="width: ${(x) => x.actualWidth}px"
  >
  </${designSystem}-text-field>
`;
/**
 *
 * @public
 * @remarks
 * HTML Element: \<foundation-string-editor\>
 */
export const foundationStringEditor = StringEditor.compose({
    baseName: 'string-editor',
    styles: agStringEditorStyles,
    template: getStringEditorTemplate(),
});
